@@ -40,9 +40,12 @@ DECLARE_FUNCTION_1P(imag_part_function)
 	
 /** Absolute value. */
 DECLARE_FUNCTION_1P(abs)
-	
+
 /** Step function. */
-DECLARE_FUNCTION_1P(step)
+DECLARE_FUNCTION_1P(unit_step)
+	
+/** Heaviside function. */
+DECLARE_FUNCTION_1P(heaviside)
 	
 /** Complex sign. */
 DECLARE_FUNCTION_1P(csgn)
@@ -74,6 +77,9 @@ DECLARE_FUNCTION_1P(exp)
 /** Natural logarithm. */
 DECLARE_FUNCTION_1P(log)
 
+/** General logarithm. */
+DECLARE_FUNCTION_2P(logb)
+
 /** Inverse sine (arc sine). */
 DECLARE_FUNCTION_1P(asin)
 
@@ -136,9 +142,6 @@ DECLARE_FUNCTION_1P(asech)
 /** Dilogarithm. */
 DECLARE_FUNCTION_1P(Li2)
 
-/** Trilogarithm. */
-DECLARE_FUNCTION_1P(Li3)
-
 /** Derivatives of Riemann's Zeta-function. */
 DECLARE_FUNCTION_2P(zetaderiv)
 
@@ -197,7 +200,7 @@ DECLARE_FUNCTION_2P(H)
 
 /** Gamma-function. */
 DECLARE_FUNCTION_1P(lgamma)
-DECLARE_FUNCTION_1P(tgamma)
+DECLARE_FUNCTION_1P(gamma)
 
 /** Beta-function. */
 DECLARE_FUNCTION_2P(beta)
@@ -227,6 +230,12 @@ DECLARE_FUNCTION_1P(factorial)
 /** Binomial function. */
 DECLARE_FUNCTION_2P(binomial)
 
+/** Rising factorial function. */
+DECLARE_FUNCTION_2P(rising_factorial)
+
+/** Falling factorial function. */
+DECLARE_FUNCTION_2P(falling_factorial)
+
 /** Hermite polynomial. */
 DECLARE_FUNCTION_2P(hermite)
 
@@ -239,6 +248,12 @@ DECLARE_FUNCTION_6P(appell_F1)
 /** Order term function (for truncated power series). */
 DECLARE_FUNCTION_1P(Order)
 
+/** Formal piecewise function */
+DECLARE_FUNCTION_1P(cases)
+
+/** Formal set-of-all function */
+DECLARE_FUNCTION_2P(set_of_all)
+
 ex lsolve(const ex &eqns, const ex &symbols, unsigned options = solve_algo::automatic);
 
 /** Find a real root of real-valued function f(x) numerically within a given
